@@ -1,5 +1,7 @@
 from checkpointing.exceptions import CheckpointNotExist
 from checkpointing.config import defaults
-from checkpointing.decorator import DecoratorCheckpoint, checkpoint, FuncCallHashIdentifier, FuncCallIdentifierBase
+from checkpointing.decorator import DecoratorCheckpoint, checkpoint
+from checkpointing.identifier import FuncCallIdentifierBase, AutoHashIdentifier
 from checkpointing.cache import CacheBase, PickleFileCache
-from checkpointing._typing import ContextId, ReturnValue
\ No newline at end of file
+from checkpointing._typing import ContextId, ReturnValue
+from checkpointing.hash.specific import register_hasher
